@@ -274,7 +274,7 @@ class MetadataManager:
             macros["longstatus"] = config.shortToLongStatus[self.status]
         else:
             macros["longstatus"] = ""
-        if self.status in ("w3c/LCWD", "w3c/FPWD", "w3c/NOTE-FPWD"):
+        if self.status in ("w3c/LCWD", "w3c/FPWD", "w3c/NOTE-FPWD", "w3c/NOTE-WD"):
             macros["status"] = "WD"
         elif self.status in ("w3c/WG-NOTE", "w3c/IG-NOTE"):
             macros["status"] = "NOTE"
